# About

My personal repository of tools to help work with the Big Data Bowl Datasets (2021 and later)

## Competition Homepages:

- [2021](https://www.kaggle.com/c/nfl-big-data-bowl-2021)
- [2022](https://www.kaggle.com/c/nfl-big-data-bowl-2022)

## Goals 

- Extract (read and parse data)
- Transform (build datasets)
- Explore (Visualization)
- Modeling (Play Outcome, Player Location, Impact, Contribution to play outcome, etc.)

## Initial Assumptions

- The data are locally available _OR_ can be referenced via a __valid file path__


